import os
import pygame

from .game import Game
from .settings import IMAGE_DIR


class Cat:
    def __init__(self, x, y, width, height):
        self.x = x;
        self.y = y;
        self.vx = x;
        self.vy = y;
        self.width = width
        self.height = height
        self.image = pygame.image.load(os.path.join(IMAGE_DIR, "cat.png"))
        self.image = pygame.transform.scale(self.image, (self.width, self.height))
        self.is_flipped_x = False

    def update(self):
        mouse_x, mouse_y = pygame.mouse.get_pos()
        self.vx = (mouse_x - self.x) / 100
        self.vy = (mouse_y - self.y) / 100

        if not self.is_flipped_x  and self.vx > 0:
            self.is_flipped_x = True
            self.flip()

        if self.is_flipped_x and self.vx < 0:
            self.is_flipped_x = False
            self.flip()

        self.x += self.vx
        self.y += self.vy

        self.x = max(min(self.x, Game().window.width), 0)
        self.y = max(min(self.y, Game().window.height), 0)
    
    def flip(self):
        self.image = pygame.transform.flip(self.image, True, False)

    def draw(self):
        from .game import Game
        Game().window.screen.blit(self.image, (self.x,self.y))




import pygame

class Window:
    def __init__(self, width, height, FPS):
        self.width = width
        self.height = height
        self.screen = pygame.display.set_mode((self.width, self.height))
        self.clock = pygame.time.Clock()
        self.FPS = FPS
        self.background_image = None

    def set_background_image(self, img_path):
        self.background_image = pygame.image.load(img_path)
        self.background_image = pygame.transform.scale(self.background_image, (self.width, self.height))

    def draw_background_image(self):
        if not self.background_image is None:
            self.screen.blit(self.background_image, (0, 0))

    def fill(self, color: pygame.Color):
        self.screen.fill(color)

    def handle_FPS(self):
        self.clock.tick(self.FPS)

    def get_screen(self):
        return self.screen



import os
import pygame

from .game import Game
from .settings import IMAGE_DIR


class Cursor:
    def __init__(self, width=32, height=32):
        self.width = width
        self.height = height
        self.image = pygame.image.load(os.path.join(IMAGE_DIR, "cursor.png"))
        self.image = pygame.transform.scale(self.image, (self.width, self.height))
        self.x = 0
        self.y = 0
        pygame.mouse.set_visible(False)

    def update(self):
        mouse_x, mouse_y = pygame.mouse.get_pos()
        self.x = mouse_x 
        self.y = mouse_y 

    def draw(self):
        Game().window.screen.blit(self.image, (self.x,self.y))





import setuptools

LONG_DESC = open("README.md").read()
VERSION = '0.1.0'
DOWNLOAD = "https://github.com/png261/meoww/archive/%s.tar.gz" % VERSION

setuptools.setup(
    name="meoww",
    version=VERSION,
    author="Phuong Nguyen",
    author_email="nhphuong.code@gmail.com",
    description="Meoww meoww meoww",
    long_description_content_type="text/markdown",
    long_description=LONG_DESC,
    keywords="meoww",
    license="MIT",
    url="https://github.com/png261/meoww",
    download_url=DOWNLOAD,
    classifiers=[
        "Environment :: X11 Applications",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],
    packages=["meoww"],
    entry_points={"console_scripts": ["meoww=meoww.__main__:main"]},
    python_requires=">=3.5",
    install_requires=[
        "pygame>=2.4.0",
    ],
    include_package_data=True,
    zip_safe=False,
)




from .game import Game

def main():
    game = Game()

    while game.isRunning:
        game.update()
        game.handle_event()
        game.render()

    game.clean()

if __name__ =="__main__":
    main()






import os
import pygame

from . import util
from .settings import IMAGE_DIR

@util.singleton
class Game:
    def __init__(self):
        from .cat import Cat
        from .window import Window
        from .cursor import Cursor

        self.FPS = 60
        self.window = Window(700, 700, 60)
        self.window.set_background_image(os.path.join(IMAGE_DIR, "background.png"))
        self.isRunning=True
        self.cursor = Cursor(50, 50)
        self.cat = Cat(0, 0, 100, 100)


    def update(self):
        self.cursor.update()
        self.cat.update()


    def handle_event(self):
        self.window.handle_FPS()
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                self.isRunning = False


    def render(self):
        self.window.fill(("white"))
        self.window.draw_background_image()

        self.cat.draw()
        self.cursor.draw()

        pygame.display.flip()


    def clean(self):
        pygame.quit()
